@@ -45,12 +45,14 @@ sub new_checker {
 
   my $path;
 
-  my $umask = 0;
+  my $umask = umask 0;
   if(defined($main->{conf}->{auto_whitelist_path})) # if undef then don't worry -- empty hash!
   {
     $path = $main->sed_path ($main->{conf}->{auto_whitelist_path});
 
-    if ($main->{locker}->safe_lock ($path)) {
+    if ($main->{locker}->safe_lock
+			($path, 30))
+    {
       $self->{locked_file} = $path;
       $self->{is_locked} = 1;
       dbg("Tie-ing to DB file R/W in $path");
